@@ -1,11 +1,25 @@
+/* $Id: cxp-gconf-pair-editor.c,v 1.8 2005/06/28 12:39:36 yasumichi Exp $ */
 /**
+ * \if japanese
  * @file
- * @brief A widget of Property dialog
+ * @brief GConfΥǥ쥯ȥˤڥΥԽ륦ɥ
  *
- * A widget of Property dialog
+ * GConfΥǥ쥯ȥˤڥΥԽ뤿Υɥ
+ * ̾ϡդˤʤͤǷꤵ롣
  * @author Yasumichi Akahoshi <yasumichi@users.sourceforge.jp>
- * @date Sun Apr 3 02:53:00 2005
- * $Revision: 1.5 $
+ * @date Thu Mar 19 2005
+ * $Revision: 1.8 $
+ * \endif
+ * \if english
+ * @file
+ * @brief Editor of GConf pair type.
+ *
+ *  Window where key to pair type that exists in specific directory of GConf is
+ * edited.The key name is decided to become unique internally.
+ * @author Yasumichi Akahoshi <yasumichi@users.sourceforge.jp>
+ * @date Thu Mar 19 2005
+ * $Revision: 1.8 $
+ * \endif
  ****************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -17,17 +31,25 @@
 #include <cxp-utils.h>
 #include <cxp-gconf-pair-editor.h>
 
+/*
+ * \if japanese
+ * @brief ꥹȥȥդ˼̤뤿
+ * \endif
+ * \if english
+ * @brief Enumeration type to identify row of list store uniquely
+ * \endif
+ */
 enum
 {
 	COL_TERMINATOR = -1,
-	COL_KEY,
-	COL_CAR,
-	COL_CDR,
-	COL_EDITABLE,
-	COL_COUNT
+	COL_KEY,	/* GConf key */
+	COL_CAR,	/* first member */
+	COL_CDR,	/* second member */
+	COL_EDITABLE,	/* Is column editable */
+	COL_COUNT	/* number of column */
 };
 
-/**
+/*
  * the private structure 
  */
 typedef struct
@@ -44,13 +66,19 @@ typedef struct
 
 static GObjectClass *parent_class = NULL;
 
+/*
+ * Enumeration type to identify properties.
+ */
 enum
 {
-	CXP_GCONF_PAIR_EDITOR_GCONF_DIR = 1,
-	CXP_GCONF_PAIR_EDITOR_C1_TITLE,
-	CXP_GCONF_PAIR_EDITOR_C2_TITLE,
+	CXP_GCONF_PAIR_EDITOR_GCONF_DIR = 1,	/* namespace of GConf */
+	CXP_GCONF_PAIR_EDITOR_C1_TITLE,		/* Title of first column header. */
+	CXP_GCONF_PAIR_EDITOR_C2_TITLE,		/* Title of second column header. */
 };
 
+/*
+ * prototype of private method.
+ */
 static void cxp_gconf_pair_editor_class_init (CxpGConfPairEditorClass * klass);
 static void cxp_gconf_pair_editor_instance_init (GTypeInstance * instance,
 						 gpointer g_class);
@@ -84,7 +112,9 @@ static void cxp_gconf_pair_editor_add_button_clicked (GtkButton * button,
 						      gpointer user_data);
 static void cxp_gconf_pair_editor_delete_button_clicked (GtkButton * button,
 							 gpointer user_data);
-
+/*
+ * the class initialization function
+ */
 static void cxp_gconf_pair_editor_class_init (CxpGConfPairEditorClass * klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
@@ -129,6 +159,9 @@ static void cxp_gconf_pair_editor_class_init (CxpGConfPairEditorClass * klass)
 	g_type_class_add_private (klass, sizeof (CxpGConfPairEditorPrivate));
 }
 
+/*
+ * the instance initialization function
+ */
 static void cxp_gconf_pair_editor_instance_init (GTypeInstance * instance,
 						 gpointer g_class)
 {
@@ -142,6 +175,9 @@ static void cxp_gconf_pair_editor_instance_init (GTypeInstance * instance,
 	private->dispose_has_run = FALSE;
 }
 
+/*
+ * the constructor function
+ */
 static GObject *cxp_gconf_pair_editor_constructor (GType type,
 						   guint n_construct_properties,
 						   GObjectConstructParam *
@@ -160,6 +196,9 @@ static GObject *cxp_gconf_pair_editor_constructor (GType type,
 	return obj;
 }
 
+/*
+ * construct widget face.
+ */
 static void cxp_gconf_pair_editor_construct_child (CxpGConfPairEditor * self)
 {
 	CxpGConfPairEditorPrivate *private =
@@ -213,6 +252,9 @@ static void cxp_gconf_pair_editor_construct_child (CxpGConfPairEditor * self)
 	cxp_gconf_pair_editor_get_all_entries (self);
 }
 
+/*
+ * the generic setter for all properties of this type.
+ */
 static void cxp_gconf_pair_editor_set_property (GObject * object,
 						guint property_id,
 						const GValue * value,
@@ -251,6 +293,9 @@ static void cxp_gconf_pair_editor_set_property (GObject * object,
 	}
 }
 
+/*
+ * the generic getter for all properties of this type.
+ */
 static void cxp_gconf_pair_editor_get_property (GObject * object,
 						guint property_id,
 						GValue * value,
@@ -276,6 +321,9 @@ static void cxp_gconf_pair_editor_get_property (GObject * object,
 	}
 }
 
+/*
+ * the dispose function
+ */
 static void cxp_gconf_pair_editor_dispose (GObject * obj)
 {
 	CxpGConfPairEditorPrivate *private =
@@ -305,12 +353,18 @@ static void cxp_gconf_pair_editor_dispose (GObject * obj)
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
+/*
+ * instance finalization function
+ */
 static void cxp_gconf_pair_editor_finalize (GObject * obj)
 {
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
+/*
+ * making externals of the list view.
+ */
 static GtkWidget *cxp_gconf_pair_editor_list_view_new (CxpGConfPairEditor *
 						       self)
 {
@@ -358,6 +412,9 @@ static GtkWidget *cxp_gconf_pair_editor_list_view_new (CxpGConfPairEditor *
 	return list_view;
 }
 
+/*
+ * The list of the entry that exists in a specific directory is obtained.
+ */
 static void cxp_gconf_pair_editor_get_all_entries (CxpGConfPairEditor * self)
 {
 	CxpGConfPairEditorPrivate *private =
@@ -398,7 +455,7 @@ static void cxp_gconf_pair_editor_get_all_entries (CxpGConfPairEditor * self)
 
 /**
  * \if japanese
- * $BA*Br$5$l$?9T$+$i(BGtkTreeRowReference$B$rF@$k!#(B
+ * 򤵤줿ԤGtkTreeRowReference롣
  * \endif
  */
 static void cxp_gconf_pair_editor_selection_foreach (GtkTreeModel * model,
@@ -415,6 +472,11 @@ static void cxp_gconf_pair_editor_selection_foreach (GtkTreeModel * model,
 	*list = g_list_append (*list, rowref);
 }
 
+/*
+ * \if japanese
+ * 뤬Խ줿ν
+ * \endif
+ */
 static void cxp_gconf_pair_editor_cell_edited (GtkCellRendererText * cell,
 					       gchar * path_string,
 					       gchar * new_text,
@@ -447,6 +509,11 @@ static void cxp_gconf_pair_editor_cell_edited (GtkCellRendererText * cell,
 	g_free (cdr);
 }
 
+/*
+ * \if japanese
+ * ɲåܥ󤬥å줿ΥХå
+ * \endif
+ */
 static void cxp_gconf_pair_editor_add_button_clicked (GtkButton * button,
 						      gpointer user_data)
 {
@@ -474,6 +541,11 @@ static void cxp_gconf_pair_editor_add_button_clicked (GtkButton * button,
 	g_free (ukey);
 }
 
+/*
+ * \if japansese
+ * ܥ󤬥å줿ΥХå
+ * \endif
+ */
 static void cxp_gconf_pair_editor_delete_button_clicked (GtkButton * button,
 							 gpointer user_data)
 {
@@ -521,6 +593,11 @@ static void cxp_gconf_pair_editor_delete_button_clicked (GtkButton * button,
 	g_list_free (list);
 }
 
+/*
+ * \if japanese
+ * GTypeƥؤϿ
+ * \endif
+ */
 GType cxp_gconf_pair_editor_get_type (void)
 {
 	static GType type = 0;
